/*
   +----------------------------------------------------------------------+
   | PHP Version 4                                                        |
   +----------------------------------------------------------------------+
   | Copyright (c) 1997-2003 The PHP Group                                |
   +----------------------------------------------------------------------+
   | This source file is subject to version 2.02 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
   | available at through the world-wide-web at                           |
   | http://www.php.net/license/2_02.txt.                                 |
   | If you did not receive a copy of the PHP license and are unable to   |
   | obtain it through the world-wide-web, please send a note to          |
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Authors: Justin Hannus <jhannus@128kb.com>                           |
   |                                                                      |
   +----------------------------------------------------------------------+
*/
 
/* $Id: opendirectory_errors.c,v 0.1 2004/01/25 09:53:01 jhannus Exp $ */

/* This file is to be included by opendirectory.c */


/**
 * OpenDirectory error strings.
 *
 * This file and its content was generated from apple's online 
 * documentation by a few handy regexp's.
 */
inline static char *php_dir_status_errstr(long status)
{
    switch (status) {
		case eDSNoErr:
			return ("No error occurred.");
		case eDSOpenFailed:
			return ("Attempt to open an Open Directory session failed.");
		case eDSCloseFailed:
			return ("Attempt to close an Open Directory session failed.");
		case eDSOpenNodeFailed:
			return ("Attempt to open a node failed.");
		case -14003: /* eDSBadDirReference */
			return ("Specified Open Directory reference is invalid.");
		case eDSNullRecordReference:
			return ("Specified record reference is empty.");
		case eDSMaxSessionsOpen:
			return ("Session limit has been reached.");
		case eDSCannotAccessSession:
			return ("Specified session is not valid.");
		case eDSDirSrvcNotOpened:
			return ("No Open Directory session has been opened.");
		case eDSNodeNotFound:
			return ("Specified node could not be found.");
		case eDSUnknownNodeName:
			return ("Node of the specified name is unknown.");
		case eDSRegisterCustomFailed:
			return ("Registration of a custom routine failed.");
		case eDSGetCustomFailed:
			return ("Unable to get a custom routine.");
		case eDSUnRegisterFailed:
			return ("Deregistration of a custom routine failed.");
		case eDSAllocationFailed:
			return ("Requested data type could not be allocated.");
		case eDSDeAllocateFailed:
			return ("Requested deallocation failed.");
		case eDSCustomBlockFailed:
			return ("Custom thread block routine failed.");
		case eDSCustomUnblockFailed:
			return ("Custom thread unblock routine failed.");
		case eDSCustomYieldFailed:
			return ("Custom yield routine failed.");
		case eDSCorruptBuffer:
			return ("Contents of buffer provided as a parameter to an Open Directory function have been corrupted.");
		case eDSInvalidIndex:
			return ("Specified index is invalid.");
		case eDSIndexOutOfRange:
			return ("Specified index is out of range.");
		case eDSIndexNotFound:
			return ("Specified index could not be found.");
		case eDSCorruptRecEntryData:
			return ("Data in a record entry structure is corrupt.");
		case eDSRefSpaceFull:
			return ("Reference table is full, so a new reference could not be allocated.");
		case eDSRefTableAllocError:
			return ("Allocation error occurred; the new reference could not be allocated.");
		case eDSInvalidReference:
			return ("Specified reference is invalid.");
		case eDSInvalidRefType:
			return ("Specified reference has an invalid type.");
		case eDSInvalidDirRef:
			return ("Specified Open Directory reference is invalid.");
		case eDSInvalidNodeRef:
			return ("Specified node reference is invalid.");
		case eDSInvalidRecordRef:
			return ("Specified record reference is invalid.");
		case eDSInvalidAttrListRef:
			return ("Specified attribute list reference is invalid.");
		case eDSInvalidAttrValueRef:
			return ("Specified attribute value reference is invalid.");
		case eDSInvalidContinueData:
			return ("Specified continuation date is invalid.");
		case eDSInvalidBuffFormat:
			return ("Specified buffer format is invalid.");
		case eDSInvalidPatternMatchType:
			return ("Specified pattern match type is invalid.");
		case eDSRefTableError:
			return ("Reference table error occurred.");
		case eDSAuthFailed:
			return ("Authentication failed.");
		case eDSAuthMethodNotSupported:
			return ("Specified authentication is not supported.");
		case eDSAuthResponseBufTooSmall:
			return ("Response buffer is too small for the response data.");
		case eDSAuthParameterError:
			return ("Authentication parameter is invalid.");
		case eDSAuthInBuffFormatError:
			return ("Buffer format error occurred during the authentication process.");
		case eDSAuthNoSuchEntity:
			return ("Specified entity does not exist.");
		case eDSAuthBadPassword:
			return ("Specified password is invalid.");
		case eDSAuthContinueDataBad:
			return ("Specified authentication continuation data is invalid.");
		case eDSAuthUnknownUser:
			return ("User is not known.");
		case eDSAuthInvalidUserName:
			return ("User name is not valid.");
		case eDSAuthCannotRecoverPasswd:
			return ("Users password could not be read.");
		case eDSAuthFailedClearTextOnly:
			return ("Cleartext authentication failed.");
		case eDSAuthNoAuthServerFound:
			return ("No authentication server was found.");
		case eDSAuthServerError:
			return ("Authentication server reported an error.");
		case eDSInvalidContext:
			return ("Continuation data does not fit with the other parameters.");
		case eDSBadContextData:
			return ("Specified continuation data is bad.");
		case eDSPermissionError:
			return ("Permission error occurred.");
		case eDSReadOnly:
			return ("Write operation was attempted.");
		case eDSInvalidDomain:
			return ("Specified domain is invalid.");
		case eNetInfoError:
			return ("NetInfo error occurred.");
		case eDSInvalidRecordType:
			return ("Specified record type is invalid.");
		case eDSInvalidAttributeType:
			return ("Specified attribute type is invalid.");
		case eDSInvalidRecordName:
			return ("Specified record name is invalid.");
		case eDSAttributeNotFound:
			return ("Specified attribute could not be found.");
		case eDSRecordAlreadyExists:
			return ("Specified record already exists.");
		case eDSRecordNotFound:
			return ("Requested record was not found.");
		case eDSAttributeDoesNotExist:
			return ("Specified attribute does not exist.");
		case eDSNoStdMappingAvailable:
			return ("Standard mapping is not available for the specified attribute.");
		case eDSInvalidNativeMapping:
			return ("Native mapping is not available for the specified attribute.");
		case eDSSchemaError:
			return ("Write operation failed because the result would conflict with the server's schema, such as trying to remove a required attribute.");
		case eDSAttributeValueNotFound:
			return ("Specified attribute value could not be obtained, set, or removed.");
		case eDSVersionMismatch:
			return ("Configuration file version is not compatible with this version of Open Directory or with the plug-in that loaded it.");
		case eDSPlugInConfigFileError:
			return ("Error occurred with the plug-ins configuration file.");
		case eDSInvalidPlugInConfigData:
			return ("case Specified plug-ins configuration data is invalid.");
		case eDSAuthNewPasswordRequired:
			return ("New password is required.");
		case eDSAuthPasswordExpired:
			return ("Password has expired.");
		case eDSAuthPasswordQualityCheckFailed:
			return ("Password does not meet security standards.");
		case eDSAuthAccountDisabled:
			return ("Account for this user is disabled.");
		case eDSAuthAccountExpired:
			return ("Account for this user has expired.");
		case eDSAuthAccountInactive:
			return ("Account for this user has become inactive due to lack of use.");
		case eDSAuthPasswordTooShort:
			return ("New password does not meet the password servers minimum length requirements; this result is returned when changing or setting a password, not when authenticating.");
		case eDSAuthPasswordTooLong:
			return ("New password does not meet the password servers maximum length limit; this result is returned when changing or setting a password, not when authenticating.");
		case eDSAuthPasswordNeedsLetter:
			return ("New password does contain a letter; this result is returned when changing or setting a password, not when authenticating.");
		case eDSAuthPasswordNeedsDigit:
			return ("New password does not contain a number; this result is returned when changing or setting a password, not when authenticating.");
		case eDSNullParameter:
			return ("Required parameter is null.");
		case eDSNullDataBuff:
			return ("Specified data buffer is null.");
		case eDSNullNodeName:
			return ("Specified node name is null.");
		case eDSNullRecEntryPtr:
			return ("Specified record entry pointer is null.");
		case eDSNullRecName:
			return ("Specified record name is null.");
		case eDSNullRecNameList:
			return ("Specified record name list is null.");
		case eDSNullRecType:
			return ("Specified record type is null.");
		case eDSNullRecTypeList:
			return ("Specified record type list is null.");
		case eDSNullAttribute:
			return ("Specified attribute is null.");
		case eDSNullAttributeAccess:
			return ("Reserved.");
		case eDSNullAttributeValue:
			return ("Specified attribute value is null.");
		case eDSNullAttributeType:
			return ("Specified attribute type is null.");
		case eDSNullAttributeTypeList:
			return ("Specified attribute type list is null.");
		case eDSNullAttributeControlPtr:
			return ("Reserved.");
		case eDSNullAttributeRequestList:
			return ("Specified attribute request list is null.");
		case eDSNullDataList:
			return ("Specified data list is empty.");
		case eDSNullDirNodeTypeList:
			return ("Specified node type list is empty.");
		case eDSNullAutMethod:
			return ("Specified authentication method is null.");
		case eDSNullAuthStepData:
			return ("Specified authentication step data is null.");
		case eDSNullAuthStepDataResp:
			return ("Specified authentication step data response is null.");
		case eDSNullNodeInfoTypeList:
			return ("Specified node information type list is null.");
		case eDSNullPatternMatch:
			return ("Specified pattern to match is null.");
		case eDSNullNodeNamePattern:
			return ("Specified node name pattern is null.");
		case eDSNullTargetArgument:
			return ("Specified target argument is null.");
		case eDSEmptyParameter:
			return ("Parameter is empty.");
		case eDSEmptyBuffer:
			return ("Buffer is empty.");
		case eDSEmptyNodeName:
			return ("Specified node name is empty.");
		case eDSEmptyRecordName:
			return ("Specified record name is empty.");
		case eDSEmptyRecordNameList:
			return ("Specified list of record names is empty.");
		case eDSEmptyRecordType:
			return ("Specified record type is empty.");
		case eDSEmptyRecordTypeList:
			return ("Specified list of record types is empty.");
		case eDSEmptyRecordEntry:
			return ("Specified record entry is empty.");
		case eDSEmptyPatternMatch:
			return ("Specified pattern is empty.");
		case eDSEmptyNodeNamePattern:
			return ("Specified node name pattern is empty.");
		case eDSEmptyAttribute:
			return ("Specified attribute is empty.");
		case eDSEmptyAttributeType:
			return ("Specified attribute type is empty.");
		case eDSEmptyAttributeTypeList:
			return ("Specified list of attribute types is empty.");
		case eDSEmptyAttributeValue:
			return ("Specified attribute value is empty.");
		case eDSEmptyAttributeRequestList:
			return ("Specified list of attribute requests is empty.");
		case eDSEmptyDataList:
			return ("Specified data list is empty.");
		case eDSEmptyNodeInfoTypeList:
			return ("Specified node information type list is empty.");
		case eDSEmptyAuthMethod:
			return ("Specified authentication method is empty.");
		case eDSEmptyAuthStepData:
			return ("Specified authentication step data is empty.");
		case eDSEmptyAuthStepDataResp:
			return ("Response to an authentication step is empty.");
		case eDSEmptyPattern2Match:
			return ("Specified pattern to match is empty.");
		case eDSBadDataNodeLength:
			return ("Specified data not length is invalid.");
		case eDSBadDataNodeFormat:
			return ("Specified data not format is invalid.");
		case eDSBadSourceDataNode:
			return ("Specified source data node is invalid.");
		case eDSBadTargetDataNode:
			return ("Specified target data node is invalid.");
		case eDSBufferTooSmall:
			return ("Attempt was made to place information in a buffer that is too small. Nothing has been placed in the buffer.");
		case eDSUnknownMatchType:
			return ("Specified match type is not known.");
		case eDSUnSupportedMatchType:
			return ("Specified match type is not supported.");
		case eDSInvalDataList:
			return ("Specified data list is invalid.");
		case eDSAttrListError:
			return ("Attribute list error occurred.");
		case eServerNotRunning:
			return ("Server is not running.");
		case eUnknownAPICall:
			return ("Unknown call was attempted.");
		case eUnknownServerError:
			return ("Server error occurred.");
		case eUnknownPlugIn:
			return ("Specified plug-in is unknown.");
		case ePlugInDataError:
			return ("Plug-in data error occurred.");
		case ePlugInNotFound:
			return ("Specified plug-in was not found.");
		case ePlugInError:
			return ("Plug-in error occurred.");
		case ePlugInInitError:
			return ("Plug-in initialization error occurred.");
		case ePlugInNotActive:
			return ("Specified plug-in is not active.");
		case ePlugInFailedToInitialize:
			return ("Specified plug-in could not initialize itself.");
		case ePlugInCallTimedOut:
			return ("Call to a plug-in timed out.");
		case eNoSearchNodesFound:
			return ("No search nodes were found.");
		case eSearchPathNotDefined:
			return ("No search path is defined.");
		case eNotHandledByThisNode:
			return ("Requested operation is not handled by the specified node.");
		case eIPCSendError:
			return ("Send error occurred.");
		case eIPCReceiveError:
			return ("Receive error occurred.");
		case eServerReplyError:
			return ("Server reply error occurred.");
		case eDSTCPSendError:
			return ("Error occurred when sending data to a remote server.");
		case eDSTCPReceiveError:
			return ("Error occured when receiving data from a remote server.");
		case eDSTCPVersionMismatch:
			return ("Mismatch of TCP versions occurred.");
		case eDSIPUnreachable:
			return ("No response from the server at the specified IP address.");
		case eDSUnknownHost:
			return ("Specified server could not be found.");
		case ePluginHandlerNotLoaded:
			return ("Plug-in handler is not loaded.");
		case eNoPluginsLoaded:
			return ("No plug-ins loaded.");
		case ePluginAlreadyLoaded:
			return ("Specified plug-in is already loaded.");
		case ePluginVersionNotFound:
			return ("Plug-ins version is not specified in its configuration file.");
		case ePluginNameNotFound:
			return ("Plug-ins name is not specified in its configuration file.");
		case eNoPluginFactoriesFound:
			return ("Plug-in factories were not found.");
		case ePluginConfigAvailNotFound:
			return ("Plug-ins property list does not contain a CFBundleConfigAvail statement.");
		case ePluginConfigFileNotFound:
			return ("Plug-ins property list does not contain a CFBundleConfigFile statement.");
		case eCFMGetFileSysRepErr:
			return ("Error occurred getting a file system report from the Code Fragment Manager.");
		case eCFPlugInGetBundleErr:
			return ("Error occurred getting the bundle for a plug-in from the Code Fragment Manager.");
		case eCFBndleGetInfoDictErr:
			return ("Error occurred getting the information dictionary for a plug-in from the Code Fragment Manager.");
		case eCFDictGetValueErr:
			return ("Error occurred getting a value from the information dictionary.");
		case eDSServerTimeout:
			return ("Server timeout occurred during authentication.");
		case eDSContinue:
			return ("Authentication can continue.");
		case eDSInvalidHandle:
			return ("Invalid handle error occurred during authentication.");
		case eDSSendFailed:
			return ("Send error occurred during authentication.");
		case eDSReceiveFailed:
			return ("Receive error occurred during authentication.");
		case eDSBadPacket:
			return ("Bad packet error occurred during authentication.");
		case eDSInvalidTag:
			return ("Invalid tag error occurred during authentication.");
		case eDSInvalidSession:
			return ("Session invalid error occurred during authentication.");
		case eDSInvalidName:
			return ("Specified name is invalid.");
		case eDSUserUnknown:
			return ("Specified user is unknown.");
		case eDSUnrecoverablePassword:
			return ("Password could not be obtained.");
		case eDSAuthenticationFailed:
			return ("Authentication failed.");
		case eDSBogusServer:
			return ("Specified server is invalid.");
		case eDSOperationFailed:
			return ("Specified operation failed during authentication.");
		case eDSNotAuthorized:
			return ("Unauthorized operation was attempted.");
		case eDSNetInfoError:
			return ("NetInfo error occurred during authentication.");
		case eDSServiceUnavailable:
			return ("Authentication service is not available.");
		case eFWGetDirNodeNameErr1:
			return ("Open Directory error occurred.");
		case eFWGetDirNodeNameErr2:
			return ("Open Directory error occurred.");
		case eFWGetDirNodeNameErr3:
			return ("Open Directory error occurred.");
		case eFWGetDirNodeNameErr4:
			return ("Open Directory error occurred.");
		case eParameterSendError:
			return ("Open Directory error occurred when sending a parameter to a plug-in.");
		case eParameterReceiveError:
			return ("Open Directory error occurred when receiving a parameter from a plug-in.");
		case eServerSendError:
			return ("Open Directory send error occurred.");
		case eServerReceiveError:
			return ("Open Directory receive error occurred.");
		case eMemoryError:
			return ("Open Directory experienced a memory error.");
		case eMemoryAllocError:
			return ("Open Directory experienced a memory allocation error.");
		case eServerError:
			return ("Server error occurred.");
		case eParameterError:
			return ("Parameter error occurred.");
		case eDataReceiveErr_NoDirRef:
			return ("No Open Directory reference was received.");
		case eDataReceiveErr_NoRecRef:
			return ("No record reference was received.");
		case eDataReceiveErr_NoAttrListRef:
			return ("No attribute list reference was received.");
		case eDataReceiveErr_NoAttrValueListRef:
			return ("No attribute list reference was received.");
		case eDataReceiveErr_NoAttrEntry:
			return ("Plug-in did not return an attribute entry.");
		case eDataReceiveErr_NoAttrValueEntry:
			return ("Plug-in did not return an attribute value entry.");
		case eDataReceiveErr_NoNodeCount:
			return ("Plug-in did not return a node count.");
		case eDataReceiveErr_NoAttrCount:
			return ("Plug-in did not return an attribute count.");
		case eDataReceiveErr_NoRecEntry:
			return ("Plug-in did not return a record entry.");
		case eDataReceiveErr_NoRecEntryCount:
			return ("Plug-in did not return a count of record entries.");
		case eDataReceiveErr_NoRecMatchCount:
			return ("Plug-in did not return a count of record matches.");
		case eDataReceiveErr_NoDataBuff:
			return ("Plug-in did not return a data buffer.");
		case eDataReceiveErr_NoContinueData:
			return ("Plug-in did not return continuation data.");
		case eDataReceiveErr_NoNodeChangeToken:
			return ("Plug-in did not provide a change token value.");
		case eNoLongerSupported:
			return ("Specified call is not supported.");
		case eUndefinedError:
			return ("Undefined error occurred.");
		case eNotYetImplemented:
			return ("Specified operation is not yet implemented.");
		default:
			return ("Unkown error code.");
	}
    return NULL;
}

